==> cogena_1.10.0.zip: cogena/NEWS.Rd <==
\name{NEWS}
\title{News for Package \pkg{cogena}}


\section{Changes in version 1.5.2 (2016-03-31)}{
\itemize{
    \item update vignette
    }
}


\section{Changes in version 1.5.1 (2015-10-30)}{
\itemize{
    \item add gmtlist2file function
    }
}

\section{Changes in version 1.5.0 (2015-10-14)}{
\itemize{
    \item Bioconductor 3.2 Dev
    }
}

\section{Changes in version 1.4.0 (2015-10-14)}{
\itemize{
    \item Bioconductor 3.2
    }
}


\section{Changes in version 1.2.0 (2015-09-01)}{
\itemize{
    \item update exmaple dataset.
    \item add drug repositioning gene sets and anlaysis.
    }
}


\section{Changes in version 1.1.6 (2015-07-14)}{
\itemize{
    \item debug cutree.
    \item values are -log2(FDR) in heatmapPEI instead of -log(FDR).
    }
}

\section{Changes in version 1.1.5 (2015-07-14)}{
\itemize{
    \item redesign cogena.
    \item add coExp and clEnrich as a substitute for the original cogena function.
    \item update vignette
    \item add tests
    \item add PPIinfo and hubGene funtions, delete PPIenrichment, netInCluster and plotPPI
    }
}

\section{Changes in version 1.1.4 (2015-07-09)}{
\itemize{
    \item add PPIenrichment function.
    \item debug pCluster function.
    }
}


\section{Changes in version 1.1.3 (2015-06-25)}{
\itemize{
    \item add heatmapEnrich, plotPPI and netInCluster functions.
    \item sampleColor randomly in heatmapCluster.
    }
}

\section{Changes in version 1.1.1 (2015-04-27)}{
\itemize{
    \item add Molecular Signatures Database v5.0.
    \item import mclust instead of suggesting it.
    }
}

\section{Changes in version 1.0.0 (2015-04-16)}{
\itemize{
    \item cogena is released with Bioconductor 3.1.
    }
}

\section{Changes in version 0.99.3 (2015-04-02)}{
\itemize{
    \item use makeCluster to creat cluster to avoid checking error from 
    Windows.
    }
}

\section{Changes in version 0.99.2 (2015-04-01)}{
\itemize{
    \item Update indent based on the coding style of Bioconductor.
    \item Trim long line.
    }
}

\section{Changes in version 0.99.1 (2015-03-31)}{
\itemize{
    \item Add runnable examples for functions.
    \item Update R version dependency from 2.10 to 3.2.
    \item Add non-empty value sections for some functions.
    }
}

\section{Changes in version 0.99.0 (2015-03-27)}{
\itemize{
    \item Submit cogena to Bioconductor.
    }
}

==> cogena_1.21.0.zip: cogena/NEWS.Rd <==
\name{NEWS}
\title{News for Package \pkg{cogena}}

\section{Changes in version 1.15.1 (2018-05-30)}{
\itemize{
    \item add dotplot in heatmapPEI and vignettes
    \item multi-group labelling
    }
}

\section{Changes in version 1.5.2 (2016-03-31)}{
\itemize{
    \item update vignette
    }
}


\section{Changes in version 1.5.1 (2015-10-30)}{
\itemize{
    \item add gmtlist2file function
    }
}

\section{Changes in version 1.5.0 (2015-10-14)}{
\itemize{
    \item Bioconductor 3.2 Dev
    }
}

\section{Changes in version 1.4.0 (2015-10-14)}{
\itemize{
    \item Bioconductor 3.2
    }
}


\section{Changes in version 1.2.0 (2015-09-01)}{
\itemize{
    \item update exmaple dataset.
    \item add drug repositioning gene sets and anlaysis.
    }
}


\section{Changes in version 1.1.6 (2015-07-14)}{
\itemize{
    \item debug cutree.
    \item values are -log2(FDR) in heatmapPEI instead of -log(FDR).
    }
}

\section{Changes in version 1.1.5 (2015-07-14)}{
\itemize{
    \item redesign cogena.
    \item add coExp and clEnrich as a substitute for the original cogena function.
    \item update vignette
    \item add tests
    \item add PPIinfo and hubGene funtions, delete PPIenrichment, netInCluster and plotPPI
    }
}

\section{Changes in version 1.1.4 (2015-07-09)}{
\itemize{
    \item add PPIenrichment function.
    \item debug pCluster function.
    }
}


\section{Changes in version 1.1.3 (2015-06-25)}{
\itemize{
    \item add heatmapEnrich, plotPPI and netInCluster functions.
    \item sampleColor randomly in heatmapCluster.
    }
}

\section{Changes in version 1.1.1 (2015-04-27)}{
\itemize{
    \item add Molecular Signatures Database v5.0.
    \item import mclust instead of suggesting it.
    }
}

\section{Changes in version 1.0.0 (2015-04-16)}{
\itemize{
    \item cogena is released with Bioconductor 3.1.
    }
}

\section{Changes in version 0.99.3 (2015-04-02)}{
\itemize{
    \item use makeCluster to creat cluster to avoid checking error from 
    Windows.
    }
}

\section{Changes in version 0.99.2 (2015-04-01)}{
\itemize{
    \item Update indent based on the coding style of Bioconductor.
    \item Trim long line.
    }
}

\section{Changes in version 0.99.1 (2015-03-31)}{
\itemize{
    \item Add runnable examples for functions.
    \item Update R version dependency from 2.10 to 3.2.
    \item Add non-empty value sections for some functions.
    }
}

\section{Changes in version 0.99.0 (2015-03-27)}{
\itemize{
    \item Submit cogena to Bioconductor.
    }
}
